package com.css.springframework.core.boot;

import com.css.springframework.core.boot.CssEnvInfoHolder;
import com.css.springframework.utils.CssSystemUtils;
import java.io.File;
import java.net.URI;
import java.net.URISyntaxException;
import java.security.CodeSource;
import java.security.ProtectionDomain;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.loader.JarLauncher;
import org.springframework.context.ApplicationContext;
import org.springframework.stereotype.Component;

@Component("cssEnvInfo")
public class CssEnvInfo implements InitializingBean {

   public static final String NAME = "cssEnvInfo";
   private ApplicationContext context;
   private boolean runInJar;
   private String jarPath;
   private String hostname;
   @Value("${spring.application.name}")
   private String applicationName;
   @Value("${server.port}")
   private int port;
   private String instanceId;


   public CssEnvInfo(ApplicationContext context) {
      this.context = context;
   }

   public void afterPropertiesSet() throws Exception {
      this.hostname = CssSystemUtils.getHostname();
      this.instanceId = this.applicationName + ":" + CssSystemUtils.getLocalIp() + ":" + this.port;
      File rootJarFile = getRootJarFile();
      if(rootJarFile != null) {
         this.runInJar = true;
         this.jarPath = rootJarFile.getCanonicalPath().replace("\\", "/");
      }

      CssEnvInfoHolder.set(this);
   }

   private static File getRootJarFile() throws URISyntaxException {
      boolean runInJarLauncher = false;
      StackTraceElement[] stackTrace = Thread.currentThread().getStackTrace();

      for(int protectionDomain = 0; protectionDomain < stackTrace.length; ++protectionDomain) {
         StackTraceElement codeSource = stackTrace[protectionDomain];
         if(codeSource.getMethodName().equals("main") && codeSource.getClassName().endsWith("JarLauncher")) {
            runInJarLauncher = true;
            break;
         }
      }

      if(runInJarLauncher) {
         ProtectionDomain var7 = JarLauncher.class.getProtectionDomain();
         CodeSource var8 = var7.getCodeSource();
         URI location = var8 != null?var8.getLocation().toURI():null;
         String path = location != null?location.getSchemeSpecificPart():null;
         File root = new File(path);
         return root.isDirectory()?null:root;
      } else {
         return null;
      }
   }

   public ApplicationContext getContext() {
      return this.context;
   }

   public boolean isRunInJar() {
      return this.runInJar;
   }

   public String getJarPath() {
      return this.jarPath;
   }

   public String getHostname() {
      return this.hostname;
   }

   public String getApplicationName() {
      return this.applicationName;
   }

   public String getInstanceId() {
      return this.instanceId;
   }

   public int getPort() {
      return this.port;
   }
}
